==> koffice-1.9.98.3.tar.bz2: koffice-1.9.98.3/plugins/textshape/dialogs/ParagraphIndentSpacing.h <==
/* This file is part of the KDE project
 * Copyright (C) 2007 Thomas Zander <zander@kde.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public License
 * along with this library; see the file COPYING.LIB.  If not, write to
 * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301, USA.
 */

#ifndef PARAGRAPHINDENTSPACING_H
#define PARAGRAPHINDENTSPACING_H

#include "ui_ParagraphIndentSpacing.h"

#include <KoUnit.h>

#include <QWidget>

class KoParagraphStyle;

class ParagraphIndentSpacing : public QWidget
{
    Q_OBJECT
public:
    ParagraphIndentSpacing(QWidget *parent);
    void open(KoParagraphStyle *style);
    void setUnit(const KoUnit &unit);

    void save();

private slots:
    void lineSpacingChanged(int);
    void useFontMetrices(bool);
    void autoTextIndentChanged(int state);

private:
    Ui::ParagraphIndentSpacing widget;

    KoParagraphStyle *m_style;
    bool m_fontMetricsChecked;
};

#endif

==> koffice-1.9.98.7.tar.bz2: koffice-1.9.98.7/plugins/textshape/dialogs/ParagraphIndentSpacing.h <==
/* This file is part of the KDE project
 * Copyright (C) 2007 Thomas Zander <zander@kde.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public License
 * along with this library; see the file COPYING.LIB.  If not, write to
 * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301, USA.
 */

#ifndef PARAGRAPHINDENTSPACING_H
#define PARAGRAPHINDENTSPACING_H

#include "ui_ParagraphIndentSpacing.h"

#include <KoUnit.h>

#include <QWidget>

class KoParagraphStyle;

class ParagraphIndentSpacing : public QWidget
{
    Q_OBJECT
public:
    ParagraphIndentSpacing(QWidget *parent);
    void setDisplay(KoParagraphStyle *style);
    void setUnit(const KoUnit &unit);

    void save(KoParagraphStyle *style);

signals:
    void firstLineMarginChanged(qreal margin);
    void leftMarginChanged(qreal margin);
    void lineSpacingChanged(double fixedLineHeight, double lineSpacing, double minimumLineHeight, int percentLineSpacing, bool useFontProperties);
    void rightMarginChanged(qreal margin);

private slots:
    void slotFirstLineMarginChanged(double margin);
    void slotLeftMarginChanged(double margin);
    void slotRightMarginChanged(double margin);
    void lineSpacingChanged(int);
    void spacingValueChanged(double value);
    void spacingPercentChanged(int percent);
    void useFontMetrices(bool);
    void autoTextIndentChanged(int state);

private:
    Ui::ParagraphIndentSpacing widget;

    KoParagraphStyle *m_style;
    bool m_fontMetricsChecked;
};

#endif
